# -*- coding: utf-8 -*-
from setuphelpers import *
import re

"""
Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()

https://calibre-ebook.com/download_linux

"""
# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls
package_name = 'calibre'


def install():
    # Declaring local variables
    package_version = control.get_software_version()

    # Installing the package
    uninstall_apt(package_name)
    print("Installing: %s" % package_name)
    run('wget -nv -O- https://download.calibre-ebook.com/linux-installer.sh | sh /dev/stdin version=%s' % package_version,timeout=1200)
    run('chmod +x calibre-uninstall')
    run('cp -f calibre-uninstall /usr/bin/calibre-uninstall')


def uninstall():
    # Uninstalling the package
    print("Uninstalling: %s" % package_name)
    run('/bin/sh /usr/bin/calibre-uninstall')


def update_package():
    # Declaring local variables
    result = False
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()
    app_name = control.name
    url = 'https://calibre-ebook.com/download_linux'

    # Getting latest version from official sources
    print("URL used is: %s" % url)
    for bs_search in bs_find_all(url,'p', proxies=proxies):
        if 'The latest release of calibre' in str(bs_search):
            version = re.search('is (.+?). ', str(bs_search).split('\n')[1]).group(1)
            break

    print("Latest %s version is: %s" % (app_name, version))

    # Changing version of the package
    if Version(version) > Version(control.get_software_version()):
        print("Software version updated (from: %s to: %s)" % (control.get_software_version(), Version(version)))
        result = True
    else:
        print("Software version up-to-date (%s)" % Version(version))
    control.version = '%s-%s' % (Version(version), control.version.split('-', 1)[-1])
    #control.set_software_version(version)
    control.save_control_to_wapt()

    # Deleting outdated binaries
    remove_outdated_binaries(version)

    # Validating or not update-package-sources
    return result

